# sphinx-rtd-size
Sphinx extension for resizing your RTD theme

## Usage

Install the package:

`pip install sphinx-rtd-size`

And in your `conf.py`:
```
    extensions = [
        ...
        'sphinx_rtd_size',
    ]
    
    sphinx_rtd_size_width = "90%"
```